---
title: "Orthodox Privilege"
date: "July 2020"
---

"Few people are capable of expressing with equanimity opinions which differ from the prejudices of their social environment. Most people are even incapable of forming such opinions."

� Einstein

There has been a lot of talk about privilege lately. Although the concept is overused, there is something to it, and in particular to the idea that privilege makes you blind � that you can't see things that are visible to someone whose life is very different from yours.

But one of the most pervasive examples of this kind of blindness is one that I haven't seen mentioned explicitly. I'm going to call it _orthodox privilege_: The more conventional-minded someone is, the more it seems to them that it's safe for everyone to express their opinions.

It's safe for _them_ to express their opinions, because the source of their opinions is whatever it's currently acceptable to believe. So it seems to them that it must be safe for everyone. They literally can't imagine a true statement that would get them in trouble.

And yet at every point in history, there were true things that would get you in terrible [trouble](say.html) to say. Is ours the first where this isn't so? What an amazing coincidence that would be.

Surely it should at least be the default assumption that our time is not unique, and that there are true things you can't say now, just as there have always been. You would think. But even in the face of such overwhelming historical evidence, most people will go with their gut on this one.

The spectral signature of orthodox privilege is "Why don't you just say it?" The more extreme will even accuse you of specific heresies they imagine you must have in mind, though if there's more than one heresy current in your time, these accusations will tend to be nondeterministic: you must either be an xist or a yist.

Frustrating as it is to deal with these people, it's important to realize that they're in earnest. They're not pretending they think it's impossible for an idea to be both unorthodox and true. The world really looks that way to them.

How do you respond to orthodox privilege? Merely giving it a name may help somewhat, because it will remind you, when you encounter it, why the people you're talking to seem so strangely unreasonable. Because this is a uniquely tenacious form of privilege. People can overcome the blindness induced by most forms of privilege by learning more about whatever they're not. But they can't overcome orthodox privilege just by learning more. They'd have to become more independent-minded. If that happens at all, it doesn't happen on the time scale of one conversation.

It may be possible to convince some people that orthodox privilege must exist even though they can't sense it, just as one can with, say, dark matter. There may be some who could be convinced, for example, that it's very unlikely that this is the first point in history at which there's nothing true you can't say, even if they can't imagine specific examples.

But except with these people, I don't think it will work to say "check your privilege" about this type of privilege, because those in its demographic don't realize they're in it. It doesn't seem to conventional-minded people that they're conventional-minded. It just seems to them that they're right. Indeed, they tend to be particularly sure of it.

Perhaps the solution is to appeal to politeness. If someone says they can hear a high-pitched noise that you can't, it's only polite to take them at their word, instead of demanding evidence that's impossible to produce, or simply denying that they hear anything. Imagine how rude that would seem. Similarly, if someone says they can think of things that are true but that cannot be said, it's only polite to take them at their word, even if you can't think of any yourself.

Once you realize that orthodox privilege exists, a lot of other things become clearer. For example, how can it be that a large number of reasonable, intelligent people worry about something they call "cancel culture," while other reasonable, intelligent people deny that it's a problem? Once you understand the concept of orthodox privilege, it's easy to see the source of this disagreement. If you believe there's nothing true that you can't say, then anyone who gets in trouble for something they say must deserve it.

**Thanks** to Sam Altman, Trevor Blackwell, Patrick Collison, Antonio Garcia-Martinez, Jessica Livingston, Robert Morris, Michael Nielsen, Geoff Ralston, Max Roser, and Harj Taggar for reading drafts of this.